/*
 * BinaryFileMatcher.cs
 *
 * File Statistics
 * Version: 1.0
 *
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 *
 * Authors: WishingBone, TCSDEVELOPER
 */

using System;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// Matches a binary file.
    /// </summary>
    ///
    /// <remarks>
    /// <para>
    /// This class depends on the result of <see cref="FileCategoryMatcher.IsBinary"/>.
    /// </para>
    /// <para>
    /// This implementation does not need any configuration.
    /// The constructor with nameSpace and prefix arguments is provided
    /// for reflection purpose only.
    /// </para>
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class BinaryFileMatcher : FileCategoryMatcher
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="BinaryFileMatcher"/> instance.
        /// </summary>
        public BinaryFileMatcher()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BinaryFileMatcher"/> instance
        /// with the specified namespace and prefix.
        /// </summary>
        ///
        /// <remarks>
        /// This constructor is provided for reflection purpose only.
        /// No work is actually performed by this constructor as
        /// no configuration is needed by this class.
        /// </remarks>
        ///
        /// <param name="nameSpace">
        /// Not applicable.
        /// </param>
        /// <param name="prefix">
        /// Not applicable.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// Any of the argument is a null reference.
        /// </exception>
        /// <exception cref="ArgumentException">
        /// <paramref name="nameSpace"/> is empty.
        /// </exception>
        public BinaryFileMatcher(string nameSpace, string prefix)
        {
            // cannot be null
            if (nameSpace == null)
            {
                throw new ArgumentNullException("nameSpace");
            }
            if (prefix == null)
            {
                throw new ArgumentNullException("prefix");
            }
            // nameSpace cannot be empty
            if (nameSpace.Trim().Length == 0)
            {
                throw new ArgumentException("'nameSpace' cannot be empty", "nameSpace");
            }
        }

        /// <summary>
        /// Decides whether the file is a binary file.
        /// </summary>
        ///
        /// <param name="isBinary">
        /// A boolean flag indicating whether the file is a binary.
        /// </param>
        ///
        /// <returns>
        /// <b>true</b> if the file is a binary file; otherwise, <b>false</b>.
        /// </returns>
        protected override bool Match(bool isBinary)
        {
            return (isBinary);
        }
    }
}
