/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/
using System;
using System.IO;
using System.Collections;
using TopCoder.File.Statistics.Processor;

namespace TopCoder.File.Statistics.AccuracyTests.Processor
{
    /// <summary>
    /// Mock implementation of FileProcessorBase, used for test purposes.
    /// </summary>
    internal class MockProcessor : FileProcessorBase
    {

        /// <summary>
        /// Just return an empty list
        /// </summary>
        public override IList SupportedMetrics
        {
            get
            {
                return new ArrayList();
            }
        }

        /// <summary>
        /// Constructor with both alias and matcher. Just call the base constructor
        /// </summary>
        ///
        /// <param name="alias">the alias for the processor</param>
        /// <param name="matcher">the file matcher</param>
        public MockProcessor(string alias, IFileMatcher matcher) : base(alias, matcher)
        {
        }

        /// <summary>
        /// This constructor loads configuration from the property. The non-empty alias and
        /// non-null file matcher are required. It Just calls the base constructor
        /// </summary>
        ///
        /// <param name="nameSpace">not null and empty, the namespace to load config from.</param>
        /// <param name="prefix">
        /// can be empty, the prefix indicates the global property level.</param>
        public MockProcessor(string nameSpace, string prefix) : base(nameSpace, prefix)
        {
        }

        /// <summary>
        /// Process the file.  This mock implementation just returns an empty stats result
        /// </summary>
        ///
        /// <param name="file">the file to process</param>
        /// <returns>an empty stats result</returns>
        ///
        /// <exception cref="ArgumentNullException">if file is null</exception>
        /// <exception cref="IOException">if io operation fails</exception>
        /// <exception cref="FileProcessingException">if processor fails</exception>
        public override StatsResult Process(FileInfo file)
        {
            return new StatsResult();
        }
    }
}