///
/// $(#)TextLineCounter.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
/// </summary>

using System;
using System.IO;
using NUnit.Framework;

using TopCoder.File.Statistics.Matcher;
using TopCoder.File.Statistics.Processor.LineCounter;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.FailureTests.Proccessor.LineCounter
{

	/// <summary>
    /// This test fixture contains the failure tests for <see cref="TextLineCounter"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class TextLineCounterTests {
	
	    /// <summary>
	    /// The namespace for this test.
	    /// </summary>
	    private const string NAMESPACE = "TopCoder.File.Statistics.Processor.LineCounter.FailureTests";
	
	    /// <summary>
	    /// The config file for this test.
	    /// </summary>
	    private const string CONFIG_FILE = "../../test_files/failuretests/processor/config.xml";
	
	    /// <summary>
	    /// The the base path of the test files.
	    /// </summary>
	    private const string BASE_PATH = "../../test_files/failuretests/processor/";
	
	    /// <summary>
	    /// An TextLineCounter instance to test.
	    /// </summary>
	    private TextLineCounter counter = null;
	
	    /// <summary>
	    /// Load the configuration before testing.
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE);
	        
	        counter = new TextLineCounter("Text", new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Remove the configuration after testing.
	    /// </summary>
	    [TearDown]
	    protected void TearDown() {
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextLineCounter1() {
            new TextLineCounter(null, new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextLineCounter2() {
	    	new TextLineCounter("alias", (IFileMatcher)null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
	    /// ArgumentException for empty String argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestTextLineCounter3() {
            new TextLineCounter(" ", new ExtensionMatcher("txt"));
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextLineCounter4() {
            new TextLineCounter(null, "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(string, string) properly throws
	    /// ArgumentException for empty argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestTextLineCounter5() {
            new TextLineCounter("", "prefix");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextLineCounter6() {
	    	new TextLineCounter("namespace", (string)null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter7() {
            new TextLineCounter(NAMESPACE, "invalid1");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter8() {
            new TextLineCounter(NAMESPACE, "invalid2");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter9() {
            new TextLineCounter(NAMESPACE, "invalid3");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter10() {
            new TextLineCounter(NAMESPACE, "invalid5");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter11() {
            new TextLineCounter(NAMESPACE, "invalid6");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter12() {
            new TextLineCounter(NAMESPACE, "invalid7");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter13() {
            new TextLineCounter(NAMESPACE, "invalid8");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor TextLineCounter(Property) properly throws
	    /// ConfigurationException for invalid property.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestTextLineCounter14() {
            new TextLineCounter(NAMESPACE, "invalid9");
	    }
	
	    /// <summary>
	    /// Tests the process method with null argument. ArgumentNullException should be thrown.
	    /// @throws IOException in case anything goes wrong
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProcess1() {
            counter.Process(null);
	    }
	
	    /// <summary>
	    /// Tests the process method with a folder as argument. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcess2() {
	    	try {
            	counter.Process(new FileInfo(BASE_PATH));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Tests the process method with invalid argument. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcess3() {
	    	try {
            	counter.Process(new FileInfo(BASE_PATH + "/inexistent_file"));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
    }
}
