///
/// $(#)BasicStatsReporting.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
/// </summary>

using System;
using System.IO;
using System.Collections;
using NUnit.Framework;

using TopCoder.File.Statistics.Reporting;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.FailureTests.Reporting
{
	/// <summary>
    /// This test fixture contains the failure tests for <see cref="BasicStatsReporting"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class StatsCollectionTests {
	
	    /// <summary>
	    /// A StatsCollection instance to test.
	    /// </summary>
	    private StatsCollection collection = null;
	
	    /// <summary>
	    /// Sets up this test.
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        collection = new StatsCollection();
	    }
	
	    /// <summary>
	    /// Checks whether the add method properly throws ArgumentNullException for 
	    /// null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAdd1() {
	    	collection.Add(null, new StatsResult());
	    }
	
	    /// <summary>
	    /// Checks whether the add method properly throws ArgumentNullException for 
	    /// null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAdd2() {
            collection.Add("key", null);
	    }
	    
	    /// <summary>
	    /// Checks whether the add method properly throws ArgumentException for 
	    /// empty String argument. 
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestAdd3() {
            collection.Add(" ", new StatsResult());
	    }
	
	    /// <summary>
	    /// Checks whether the add method properly throws ArgumentNullException for 
	    /// null argument. 
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestGet1() {
	    	object o = collection[null];
	    }
	    
	    /// <summary>
	    /// Checks whether the get method properly throws ArgumentException for 
	    /// empty String argument. 
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestGet2() {
	    	object o = collection[" "];
	    }
    }
}
