///
/// $(#)StatsResultsTests.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
///

using System;
using NUnit.Framework;

namespace TopCoder.File.Statistics.FailureTests
{
	/// <summary>
    /// This test fixture contains the failure tests for <see cref="StatsResult"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class StatsResultTests {
	
	    /// <summary>
	    /// A StatsResult instance to test.
	    /// </summary>
	    private StatsResult result = null;
	    
	    /// <summary>
	    /// Creates an empty StatsResult instance.
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        result = new StatsResult();
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor StatsResult(StatsResult) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestStatsResult() {
            new StatsResult(null);
	    }
	    
	    /// <summary>
	    /// Checks whether the method setStat(Metric, long) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestSetStat() {
	    	result[null] = 1;
	    }
	    
	    /// <summary>
	    /// Checks whether the method getStat(Metric) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestGetStat1() {
	    	object o = result[null];
	    }
	    
	    /// <summary>
	    /// Checks whether the method getStat(Metric) properly throws
	    /// ArgumentException for invalid argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestGetStat2() {
	    	object o = result[new Metric("metric", "metric", "A metric")];
	    }
	    
	    /// <summary>
	    /// Checks whether the method getStat(Metric) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAggregate() {
            result.Aggregate(null);
	    }
    }
}
