using System;
using System.IO;
using System.Collections;
using TopCoder.Util.ConfigurationManager;
using TopCoder.File.Statistics.Processor;
namespace TopCoder.File.Statistics.StressTests
{
	/// <summary>
	/// Does nothing
	/// </summary>
	public class NopProcessor : FileProcessorBase
	{
		/// <summary>
		/// The name of the metric used for this processor.
		/// </summary>
		public static readonly string Name = "NOP";

		/// <summary>
		/// The display name of the metric used for this processor.
		/// </summary>
		public static readonly string DisplayName = "Nothing";

		/// <summary>
		/// The description of the metric used for this processor.
		/// </summary>
		private static readonly string Description = "Does nothing";

		/// <summary>
		/// The supported metric list, contain a single metric.
		/// </summary>
		private IList supportedMetrics = new ArrayList();

		/// <summary>
		/// Return a list contains single <see cref="Metric"/> composed of the <see cref="Name"/>,
		/// <see cref="DisplayName"/> and a description.
		/// </summary>
		///
		/// <value>Represents the list of the supported metric.</value>
		public override IList SupportedMetrics
		{
			get
			{
				return this.supportedMetrics;
			}
		}

		/// <summary>
		/// Propagate to super constructor.
		/// </summary>
		///
		/// <param name="alias">the alias</param>
		/// <param name="matcher">the file matcher</param>
		///
		/// <exception cref="ArgumentNullException">if alias or matcher is null</exception>
		/// <exception cref="ArgumentException">if alias is empty after trimmed</exception>
		public NopProcessor(string alias, IFileMatcher matcher) : base(alias, matcher)
		{
		}

		/// <summary>
		/// Propagate to super constructor.
		/// </summary>
		///
		/// <param name="nameSpace">not null and empty, the namespace to load config from.</param>
		/// <param name="prefix">
		/// can be empty, the prefix indicates the global property level.</param>
		///
		/// <exception cref="ArgumentNullException">if nameSpace or prefix is null</exception>
		/// <exception cref="ArgumentException">if nameSpace is emtpy</exception>
		/// <exception cref="ConfigurationException">if config error occurs</exception>
		public NopProcessor(string nameSpace, string prefix) : base(nameSpace, prefix)
		{
		}

		/// <summary>
		/// Count the lines in text file.
		/// </summary>
		///
		/// <param name="file">the file to process</param>
		/// <returns>the line count result</returns>
		///
		/// <exception cref="ArgumentNullException">if file is null</exception>
		/// <exception cref="IOException">if io operation fails</exception>
		public override StatsResult Process(FileInfo file)
		{
			StatsResult result = new StatsResult();
			result[(Metric) this.supportedMetrics[0]] = -1;

			return result;
		}
	}
}